@@ -1,5 +1,6 @@
 #cqlengine exceptions
-class CQLEngineException(BaseException): pass
+class CQLEngineException(Exception): pass
 class ModelException(CQLEngineException): pass
 class ValidationError(CQLEngineException): pass
 
+class UndefinedKeyspaceException(CQLEngineException): pass
