@@ -1,6 +1,7 @@
 from datetime import datetime, timedelta
 import json
 from uuid import uuid4
+import six
 
 from cqlengine import Model, ValidationError
 from cqlengine import columns
@@ -22,7 +23,7 @@ class JsonTestColumn(columns.Column):
 
     def to_python(self, value):
         if value is None: return
-        if isinstance(value, basestring):
+        if isinstance(value, six.string_types):
             return json.loads(value)
         else:
             return value
@@ -225,7 +226,7 @@ class TestListColumn(BaseCassEngTestCase):
 
     def test_partial_updates(self):
         """ Tests that partial udpates work as expected """
-        final = range(10)
+        final = list(range(10))
         initial = final[3:7]
         m1 = TestListModel.create(int_list=initial)
 
